@@ -138,12 +138,13 @@ class LaunchPad(FWSerializable):
             self.m_logger.info('Performing maintenance on Launchpad...')
 
             self.m_logger.debug('Tracking down FIZZLED jobs...')
-            fl = self.detect_fizzled(fix=True)
+            fl, ff = self.detect_lostruns(fizzle=True)
             if fl:
                 self.m_logger.info('Detected {} FIZZLED launches: {}'.format(len(fl), fl))
+                self.m_logger.info('Detected {} FIZZLED FWs: {}'.format(len(ff), ff))
 
             self.m_logger.debug('Tracking down stuck RESERVED jobs...')
-            ur = self.detect_unreserved(fix=True)
+            ur = self.detect_unreserved(rerun=True)
             if ur:
                 self.m_logger.info('Unreserved {} RESERVED launches: {}'.format(len(ur), ur))
 
@@ -435,7 +436,7 @@ class LaunchPad(FWSerializable):
         for fw in self.fireworks.find({'launches': launch_id, 'state': 'RESERVED'}, {'fw_id': 1}):
             self.fireworks.find_and_modify({'fw_id': fw['fw_id']}, {'$set': {'state': 'READY'}})
 
-    def detect_unreserved(self, expiration_secs=FWConfig().RESERVATION_EXPIRATION_SECS, fix=False):
+    def detect_unreserved(self, expiration_secs=FWConfig().RESERVATION_EXPIRATION_SECS, rerun=False):
         bad_launch_ids = []
         now_time = datetime.datetime.utcnow()
         cutoff_timestr = (now_time - datetime.timedelta(seconds=expiration_secs)).isoformat()
@@ -444,7 +445,7 @@ class LaunchPad(FWSerializable):
                                              {'launch_id': 1})
         for ld in bad_launch_data:
             bad_launch_ids.append(ld['launch_id'])
-        if fix:
+        if rerun:
             for lid in bad_launch_ids:
                 self.unreserve(lid)
         return bad_launch_ids
@@ -462,19 +463,37 @@ class LaunchPad(FWSerializable):
             wf = self.get_wf_by_fw_id(fw_id)
             self._refresh_wf(wf, fw_id)
 
-    def detect_fizzled(self, expiration_secs=FWConfig().RUN_EXPIRATION_SECS, fix=False):
+    def detect_lostruns(self, expiration_secs=FWConfig().RUN_EXPIRATION_SECS, fizzle=False, rerun=False, max_runtime=None):
         bad_launch_ids = []
+        bad_fw_ids = []
         now_time = datetime.datetime.utcnow()
         cutoff_timestr = (now_time - datetime.timedelta(seconds=expiration_secs)).isoformat()
         bad_launch_data = self.launches.find({'state': 'RUNNING', 'state_history': {
             '$elemMatch': {'state': 'RUNNING', 'updated_on': {'$lte': cutoff_timestr}}}},
-                                             {'launch_id': 1})
+                                             {'launch_id': 1, 'fw_id': 1})
         for ld in bad_launch_data:
-            bad_launch_ids.append(ld['launch_id'])
-        if fix:
+            bad_launch = False
+            if max_runtime:
+                m_l = self.get_launch_by_id(ld['launch_id'])
+                utime = m_l._get_time('RUNNING', use_update_time=True)
+                ctime = m_l._get_time('RUNNING', use_update_time=False)
+                if (utime-ctime).seconds <= max_runtime:
+                    bad_launch=True
+
+            if not max_runtime or bad_launch:
+                bad_launch_ids.append(ld['launch_id'])
+                bad_fw_ids.append(ld['fw_id'])
+        if fizzle or rerun:
             for lid in bad_launch_ids:
                 self.mark_fizzled(lid)
-        return bad_launch_ids
+        if rerun:
+            for fw_id in bad_fw_ids:
+                # only rerun if the FireWork has 'FIZZLED' state. It is possible that
+                # a different Launch for the same FireWork is 'COMPLETED'
+                if self.fireworks.find_one({"fw_id": fw_id, "state": "FIZZLED"}):
+                    self.rerun_fw(fw_id)
+
+        return bad_launch_ids, bad_fw_ids
 
     def _set_reservation_id(self, launch_id, reservation_id):
         m_launch = self.get_launch_by_id(launch_id)
