@@ -115,12 +115,15 @@ def lpad():
     reservation_parser = subparsers.add_parser('detect_unreserved', help='Find launches with stale reservations')
     reservation_parser.add_argument('--time', help='expiration time (seconds)',
                                     default=FWConfig().RESERVATION_EXPIRATION_SECS, type=int)
-    reservation_parser.add_argument('--mark', help='cancel bad reservations', action='store_true')
+    reservation_parser.add_argument('--rerun', help='cancel and rerun expired reservations', action='store_true')
 
-    fizzled_parser = subparsers.add_parser('detect_fizzled', help='Find launches that have FIZZLED')
+    fizzled_parser = subparsers.add_parser('detect_lostruns', help='Find launches that have FIZZLED')
     fizzled_parser.add_argument('--time', help='expiration time (seconds)', default=FWConfig().RUN_EXPIRATION_SECS,
                                 type=int)
-    fizzled_parser.add_argument('--mark', help='mark fizzled', action='store_true')
+    fizzled_parser.add_argument('--fizzle', help='mark lost runs as fizzled', action='store_true')
+    fizzled_parser.add_argument('--rerun', help='rerun lost runs', action='store_true')
+    fizzled_parser.add_argument('--max_runtime', help='max runtime, helpful for tracing down walltime kills (seconds)', default=None,
+                                type=int)
 
     defuse_parser = subparsers.add_parser('defuse', help='cancel (de-fuse) an entire Workflow')
     defuse_parser.add_argument('-i', '--fw_id', help='fw id or comma separated list of fw ids', default=None)
@@ -197,7 +200,7 @@ def lpad():
 
     webgui_parser.add_argument("--host", dest="host", type=str, default="127.0.0.1",
                         help="Host to run the server on (default: 127.0.0.1)")
-    webgui_parser.add_argument('-b', '--browser', help='launch browser', action='store_true')
+    webgui_parser.add_argument('-s', '--server_mode', help='run in server mode (skip opening the browser)', action='store_true')
 
     addscript_parser = subparsers.add_parser('add_scripts', help='quickly add a script (or several scripts) to run in sequence')
     addscript_parser.add_argument('scripts', help="Script to run, or delimiter-separated scripts (default comma-separated)")
@@ -236,11 +239,13 @@ def lpad():
                     raise ValueError('Operation aborted by user.')
             lp.reset(args.password)
 
-        elif args.command == 'detect_fizzled':
-            print lp.detect_fizzled(args.time, args.mark)
+        elif args.command == 'detect_lostruns':
+            fl,ff = lp.detect_lostruns(expiration_secs=args.time, fizzle=args.fizzle, rerun=args.rerun, max_runtime=args.max_runtime)
+            lp.m_logger.debug('Detected {} FIZZLED launches: {}'.format(len(fl), fl))
+            lp.m_logger.info('Detected {} FIZZLED FWs: {}'.format(len(ff), ff))
 
         elif args.command == 'detect_unreserved':
-            print lp.detect_unreserved(args.time, args.mark)
+            print lp.detect_unreserved(expiration_secs=args.time, rerun=args.rerun)
 
         elif args.command == 'add':
             fwf = Workflow.from_file(args.wf_file)
@@ -408,7 +413,7 @@ def lpad():
             lp.m_logger.info('Finished refreshing {} Workflows'.format(len(fw_ids)))
 
         elif args.command == 'set_priority':
-            fw_ids = parse_helper(lp, args, wf_mode=True)
+            fw_ids = parse_helper(lp, args)
             for f in fw_ids:
                 lp.set_priority(f, args.priority)
                 lp.m_logger.debug("Processed fw_id {}".format(f))
@@ -422,7 +427,7 @@ def lpad():
             p1 = Process(target=call_command,
                          args=("runserver",  "{}:{}".format(args.host, args.port)))
             p1.start()
-            if args.browser:
+            if not args.server_mode:
                 time.sleep(2)
                 webbrowser.open("http://{}:{}".format(args.host, args.port))
             p1.join()
